@@ -136,7 +136,7 @@ void ExerciseWindow::loadExercise(QList<QString> name)
         myThread->start(QThread::NormalPriority);
     }
 
-    if(firstTime == true)
+    if(firstTime == true && exercises.count() > 1)
     {
         ed = new ExerciseDialog(this);
         connect(ed,SIGNAL(exerciseName(QString)),this, SLOT(setCurrentExercise(QString)));
